@@ -1,7 +1,7 @@
 /* vim:set et sts=4: */
 /* input-pad - The input pad
- * Copyright (C) 2010-2011 Takao Fujiwara <takao.fujiwara1@gmail.com>
- * Copyright (C) 2010-2011 Red Hat, Inc.
+ * Copyright (C) 2010-2014 Takao Fujiwara <takao.fujiwara1@gmail.com>
+ * Copyright (C) 2010-2014 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,17 +24,22 @@
 #endif
 
 #include "input-pad.h"
+#include <stdlib.h> /* exit */
 
 int
 main (int argc, char *argv[])
 {
     void *data;
+    int do_exit = 0;
+    int retval;
 
-    input_pad_window_init (&argc, &argv, 0);
+    retval = input_pad_window_init (&argc, &argv, 0, &do_exit);
 
-    data = input_pad_window_new (0);
-    input_pad_window_show (data);
+    if (do_exit) {
+        exit (retval);
+    }
 
-    input_pad_window_main (data);
-    return 0;
+    data = input_pad_window_new ();
+
+    return input_pad_window_main (data);
 }
